@@ -19,12 +19,12 @@ real function tetens( T, dl )  ! ƥƥμ¸Ѥ˰¿׻.
   implicit none
   real, intent(in) :: T  ! 絤β [K]
   integer, intent(in), optional :: dl  ! ǥХå٥
-  real, parameter :: a=7.5, b=237.3, c=9.5, d=265.5
+  real, parameter :: a=17.269e0, b=-35.86e0, c=21.875e0, d=-7.66e0
 
   if(t<=t0)then
-     tetens=e0*10.0**(c*(t-t0)/(t-t0+d))
+     tetens=610.78e0*exp(c*(t-t0)/(t+d))
   else
-     tetens=e0*10.0**(a*(t-t0)/(t-t0+b))
+     tetens=610.78e0*exp(a*(t-t0)/(t+b))
   end if
 
   if(present(dl))then
